@@ -2,33 +2,37 @@
 
 
 package HiD;
-our $AUTHORITY = 'cpan:GENEHACK';
-$HiD::VERSION = '1.95_94'; # TRIAL
+$HiD::VERSION = '1.8'; # TRIAL
 use Moose;
 use namespace::autoclean;
 # note: we also do 'with HiD::Role::DoesLogging', just later on because reasons.
 
-use 5.014; # strict, unicode_strings
+use 5.014;
 use utf8;
+use strict;
 use autodie;
 use warnings;
 use warnings    qw/ FATAL  utf8     /;
 use open        qw/ :std  :utf8     /;
 use charnames   qw/ :full           /;
+use feature     qw/ unicode_strings /;
 
-use Class::Load        qw/ try_load_class /;
+use Class::Load        qw/ :all /;
 use DateTime;
+use File::Basename;
 use File::Find::Rule;
-use Path::Tiny;
-use Try::Tiny;
-use YAML::Tiny;
-
+use File::Path         qw/ make_path /;
+use File::Remove       qw/ remove /;
 use HiD::File;
 use HiD::Layout;
 use HiD::Page;
 use HiD::Pager;
 use HiD::Post;
 use HiD::Types;
+use Module::Find;
+use Path::Class        qw/ file /;
+use Try::Tiny;
+use YAML::XS           qw/ LoadFile /;
 
 
 has categories => (
@@ -76,7 +80,7 @@ sub _build_config {
 
   if ( my $file = $self->config_file ) {
     try {
-      $config = YAML::Tiny->read( $file )->[0] // {};
+      $config = LoadFile( $file ) // {};
       ref $config eq 'HASH' or die $!;
       $config_loaded++;
     };
@@ -126,7 +130,7 @@ has destination => (
   lazy    => 1 ,
   default => sub {
     my $dest = shift->get_config( 'destination' );
-    path( $dest )->mkpath() unless -e -d $dest;
+    make_path $dest unless -e -d $dest;
     return $dest;
   },
 );
@@ -612,10 +616,9 @@ sub publish {
   my( $self ) = @_;
 
   if ( -e $self->destination && $self->get_config( 'clean_destination' )){
-    my $path = path( $self->destination );
-    $path->remove_tree();
+    remove( \1 , $self->destination );
     $self->INFO( "cleaned destination directory" );
-    $path->mkpath();
+    make_path $self->destination;
   }
 
   $self->INFO( "publish" );
@@ -674,19 +677,16 @@ sub publish {
 
     $self->INFO( sprintf "* Published %s" , $file->output_filename );
 
-    my $path = path( $file->output_filename );
-    while ( $path ne '.' ) {
-      $self->add_written_file( $path->stringify() => 1 );
-      $path = $path->parent;
+    my $path;
+    foreach my $part ( split '/' , $file->output_filename ) {
+      $path = file( $path , $part )->stringify;
+      $self->add_written_file( $path => 1 );
     }
   }
 
   if ( $self->remove_unwritten_files ) {
     foreach ( File::Find::Rule->in( $self->destination )) {
-      next if $self->wrote_file($_);
-
-      my $path = path( $_ );
-      $path->is_dir ? $path->remove_tree : $path->remove;
+      $self->wrote_file($_) or remove \1 , $_;
     }
   }
 
@@ -987,7 +987,7 @@ L<StaticVolt>
 
 =head1 VERSION
 
-version 1.95_94
+version 1.8
 
 =head1 AUTHOR
 
@@ -995,7 +995,7 @@ John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by John SJ Anderson.
+This software is copyright (c) 2014 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
