@@ -2,18 +2,18 @@
 
 
 package HiD::App::Command;
-our $AUTHORITY = 'cpan:GENEHACK';
-$HiD::App::Command::VERSION = '1.95_94'; # TRIAL
+$HiD::App::Command::VERSION = '1.8'; # TRIAL
 use Moose;
 extends 'MooseX::App::Cmd::Command';
 use namespace::autoclean;
 
-use 5.014;  # strict, unicode_strings
+use 5.014;
 use utf8;
 use autodie;
 use warnings    qw/ FATAL  utf8     /;
 use open        qw/ :std  :utf8     /;
 use charnames   qw/ :full           /;
+use feature     qw/ unicode_strings /;
 
 use HiD;
 
@@ -133,7 +133,7 @@ stored configuration information, and return it.
 
 =head1 VERSION
 
-version 1.95_94
+version 1.8
 
 =head1 AUTHOR
 
@@ -141,7 +141,7 @@ John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by John SJ Anderson.
+This software is copyright (c) 2014 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
