@@ -2,26 +2,25 @@
 
 
 package HiD::App::Command::config;
-our $AUTHORITY = 'cpan:GENEHACK';
-$HiD::App::Command::config::VERSION = '1.95_94'; # TRIAL
+$HiD::App::Command::config::VERSION = '1.8'; # TRIAL
 use Moose;
 extends 'HiD::App::Command';
 use namespace::autoclean;
 
-use 5.014;  # strict, unicode_strings
+use 5.014;
 use utf8;
 use autodie;
 use warnings    qw/ FATAL  utf8     /;
 use open        qw/ :std  :utf8     /;
 use charnames   qw/ :full           /;
-
-use Data::Printer return_value => 'dump';
+use feature     qw/ unicode_strings /;
 
 sub _run {
   my( $self , $opts , $args ) = @_;
 
   $args = [ 'config' ] unless $args->[0];
 
+  use DDP;
   my $out;
   $out .= p $self->hid->$_ foreach @$args;
 
@@ -69,7 +68,7 @@ sub commands.
 
 =head1 VERSION
 
-version 1.95_94
+version 1.8
 
 =head1 AUTHOR
 
@@ -77,7 +76,7 @@ John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by John SJ Anderson.
+This software is copyright (c) 2014 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
