@@ -2,20 +2,20 @@
 
 
 package HiD::App::Command::init;
-our $AUTHORITY = 'cpan:GENEHACK';
-$HiD::App::Command::init::VERSION = '1.95_94'; # TRIAL
+$HiD::App::Command::init::VERSION = '1.8'; # TRIAL
 use Moose;
 extends 'HiD::App::Command';
 use namespace::autoclean;
 
-use 5.014; # strict, unicode_strings
+use 5.014;
 use utf8;
 use autodie;
 use warnings    qw/ FATAL  utf8     /;
 use open        qw/ :std  :utf8     /;
 use charnames   qw/ :full           /;
+use feature     qw/ unicode_strings /;
 
-use YAML::Tiny;
+use YAML::XS qw/ DumpFile /;
 
 
 has blog => (
@@ -62,8 +62,9 @@ EOF
 
   $self->_init_blog if $self->blog;
 
-  my $yaml = YAML::Tiny->new({ title => $self->title });
-  $yaml->write( '_config.yml' );
+  DumpFile( '_config.yml' , {
+    title => $self->title ,
+  });
 
   say "Enjoy your new site!";
 }
@@ -148,7 +149,7 @@ sub commands.
 
 =head1 VERSION
 
-version 1.95_94
+version 1.8
 
 =head1 AUTHOR
 
@@ -156,7 +157,7 @@ John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by John SJ Anderson.
+This software is copyright (c) 2014 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
