@@ -2,14 +2,13 @@
 
 
 package HiD::App::Command::server;
-our $AUTHORITY = 'cpan:GENEHACK';
-$HiD::App::Command::server::VERSION = '1.95_94'; # TRIAL
+$HiD::App::Command::server::VERSION = '1.8'; # TRIAL
 use Moose;
 extends 'HiD::App::Command';
 with 'HiD::Role::PublishesDrafts';
 use namespace::autoclean;
 
-use 5.014;  # strict, unicode_strings
+use 5.014;
 use utf8;
 use autodie;
 use warnings    qw/ FATAL  utf8     /;
@@ -17,7 +16,9 @@ use open        qw/ :std  :utf8     /;
 use charnames   qw/ :full           /;
 use feature     qw/ unicode_strings /;
 
-use Class::Load      qw/ try_load_class /;
+use namespace::autoclean;
+
+use Class::Load      qw/ :all /;
 use Plack::Builder;
 use Plack::Runner;
 
@@ -176,7 +177,7 @@ sub commands.
 
 =head1 VERSION
 
-version 1.95_94
+version 1.8
 
 =head1 AUTHOR
 
@@ -184,7 +185,7 @@ John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by John SJ Anderson.
+This software is copyright (c) 2014 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
