@@ -2,22 +2,22 @@
 
 
 package HiD::Layout;
-our $AUTHORITY = 'cpan:GENEHACK';
-$HiD::Layout::VERSION = '1.95_94'; # TRIAL
+$HiD::Layout::VERSION = '1.8'; # TRIAL
 use Moose;
 use namespace::autoclean;
 
-use 5.014;  # strict, unicode_strings
+use 5.014;
 use utf8;
 use autodie;
 use warnings    qw/ FATAL  utf8     /;
 use open        qw/ :std  :utf8     /;
 use charnames   qw/ :full           /;
+use feature     qw/ unicode_strings /;
 
-use Path::Tiny;
-use YAML::Tiny  qw/ Load /;
-
+use Encode;
+use File::Slurp qw/ read_file / ;
 use HiD::Types;
+use YAML::XS;
 
 
 has content => (
@@ -81,14 +81,14 @@ sub BUILDARGS {
     ( $args{name} , $args{ext} ) = $args{filename}
       =~ m|^.*/(.+)\.([^.]+)$|;
 
-    my $content  = path( $args{filename} )->slurp_utf8;
+    my $content  = read_file( $args{filename}, binmode => ':utf8' );
     my $metadata = {};
 
     if ( $content =~ /^---\n/s ) {
       my $meta;
       ( $meta , $content ) = ( $content )
         =~ m|^---\n(.*?)---\n(.*)$|s;
-      $metadata = Load( $meta ) if $meta;
+      $metadata = Load( encode('utf8', $meta) ) if $meta;
     }
 
     $args{metadata} = $metadata;
@@ -203,7 +203,7 @@ Will recurse into embedded layouts as needed.
 
 =head1 VERSION
 
-version 1.95_94
+version 1.8
 
 =head1 AUTHOR
 
@@ -211,7 +211,7 @@ John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by John SJ Anderson.
+This software is copyright (c) 2014 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
