@@ -2,20 +2,21 @@
 
 
 package HiD::Pager;
-our $AUTHORITY = 'cpan:GENEHACK';
-$HiD::Pager::VERSION = '1.95_94'; # TRIAL
+$HiD::Pager::VERSION = '1.8'; # TRIAL
 use Moose;
 # note: we also do 'with HiD::Role::DoesLogging', just later on because reasons.
 
 use namespace::autoclean;
 
-use 5.014;  # strict, unicode_strings
+use 5.014;
 use utf8;
+use strict;
 use autodie;
 use warnings;
 use warnings    qw/ FATAL  utf8     /;
 use open        qw/ :std  :utf8     /;
 use charnames   qw/ :full           /;
+use feature     qw/ unicode_strings /;
 
 use Data::Page;
 use String::Errf    qw/ errf /;
@@ -255,7 +256,7 @@ Returns the URL for the previous page in the set.
 
 =head1 VERSION
 
-version 1.95_94
+version 1.8
 
 =head1 AUTHOR
 
@@ -263,7 +264,7 @@ John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by John SJ Anderson.
+This software is copyright (c) 2014 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
