@@ -2,16 +2,16 @@
 
 
 package HiD::Plugin;
-our $AUTHORITY = 'cpan:GENEHACK';
-$HiD::Plugin::VERSION = '1.95_94'; # TRIAL
+$HiD::Plugin::VERSION = '1.8'; # TRIAL
 use Moose;
 use namespace::autoclean;
 
-use 5.014;  # strict, unicode_strings
+use 5.014;
 use utf8;
 use autodie;
 use warnings   qw/ FATAL utf8 /;
 use charnames  qw/ :full           /;
+use feature    qw/ unicode_strings /;
 
 
 sub after_publish { 1 }
@@ -43,7 +43,7 @@ Base class for plugin object
 
 =head1 VERSION
 
-version 1.95_94
+version 1.8
 
 =head1 AUTHOR
 
@@ -51,7 +51,7 @@ John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by John SJ Anderson.
+This software is copyright (c) 2014 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
