@@ -2,8 +2,7 @@
 
 
 package HiD::Post;
-our $AUTHORITY = 'cpan:GENEHACK';
-$HiD::Post::VERSION = '1.95_94'; # TRIAL
+$HiD::Post::VERSION = '1.8'; # TRIAL
 use Moose;
 with
   'HiD::Role::IsConverted',
@@ -14,14 +13,16 @@ with 'HiD::Role::DoesLogging'; # this one last b/c it needs method delegated
 
 use namespace::autoclean;
 
-use 5.014;  # strict, unicode_strings
+use 5.014;
 use utf8;
 use autodie;
 use warnings    qw/ FATAL  utf8     /;
 use open        qw/ :std  :utf8     /;
 use charnames   qw/ :full           /;
+use feature     qw/ unicode_strings /;
 
-use Path::Tiny;
+use File::Basename  qw/ fileparse /;
+use File::Path      qw/ make_path /;
 use String::Errf    qw/ errf /;
 
 
@@ -44,12 +45,13 @@ sub get_default_layout { 'post' }
 sub publish {
   my $self = shift;
 
-  my $out = path( $self->output_filename );
+  my( undef , $dir ) = fileparse( $self->output_filename );
 
-  my $dir = $out->parent;
-  $dir->mkpath unless $dir->is_dir;
+  make_path $dir unless -d $dir;
 
-  $out->spew_utf8( $self->rendered_content );
+  open( my $out , '>:utf8' , $self->output_filename ) or die $!;
+  print $out $self->rendered_content;
+  close( $out );
 }
 
 # override
@@ -58,7 +60,7 @@ my $date_regex = qr|([0-9]{4})-([0-9]{1,2})-([0-9]{1,2})|;
 sub _build_basename {
   my $self = shift;
   my $ext = '.' . $self->ext;
-  my $basename = path( $self->input_filename )->basename( $ext );
+  my $basename = fileparse( $self->input_filename , $ext );
 
   if( $self->get_config( 'publish_drafts' )) {
     if ( $self->is_draft ) {
@@ -75,7 +77,6 @@ sub _build_basename {
 sub _build_url {
   my $self = shift;
 
-  ### FIXME this is all horribly bigoted towards unix-ish file paths
   my %formats = (
     simple => '/posts/%{year}/%{month}/%{title}.html',
     date   => '/%{categories}s/%{year}s/%{month}s/%{day}s/%{title}s.html' ,
@@ -150,7 +151,7 @@ disk -- this data from this object.
 
 =head1 VERSION
 
-version 1.95_94
+version 1.8
 
 =head1 AUTHOR
 
@@ -158,7 +159,7 @@ John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by John SJ Anderson.
+This software is copyright (c) 2014 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
