@@ -2,17 +2,18 @@
 
 
 package HiD::Processor;
-our $AUTHORITY = 'cpan:GENEHACK';
-$HiD::Processor::VERSION = '1.95_94'; # TRIAL
+$HiD::Processor::VERSION = '1.8'; # TRIAL
 use Moose;
 use namespace::autoclean;
 
-use 5.014; # strict, unicode_strings
+use 5.014;
 use utf8;
 use autodie;
 use warnings    qw/ FATAL  utf8     /;
 use open        qw/ :std  :utf8     /;
 use charnames   qw/ :full           /;
+use feature     qw/ unicode_strings /;
+
 
 ### FIXME figure out whether this makes more sense as a role that would make
 ###       it easier to see as something implementing a particular interface,
@@ -52,7 +53,7 @@ implements a 'process' method.
 
 =head1 VERSION
 
-version 1.95_94
+version 1.8
 
 =head1 AUTHOR
 
@@ -60,7 +61,7 @@ John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by John SJ Anderson.
+This software is copyright (c) 2014 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
