@@ -2,18 +2,18 @@
 
 
 package HiD::Processor::IIBlog;
-our $AUTHORITY = 'cpan:GENEHACK';
-$HiD::Processor::IIBlog::VERSION = '1.95_94'; # TRIAL
+$HiD::Processor::IIBlog::VERSION = '1.8'; # TRIAL
 use Moose;
 extends 'HiD::Processor';
 use namespace::autoclean;
 
-use 5.014; # strict, unicode_strings
+use 5.014;
 use utf8;
 use autodie;
 use warnings    qw/ FATAL  utf8     /;
 use open        qw/ :std  :utf8     /;
 use charnames   qw/ :full           /;
+use feature     qw/ unicode_strings /;
 
 use Text::Xslate;
 
@@ -78,7 +78,7 @@ publication.
 
 =head1 VERSION
 
-version 1.95_94
+version 1.8
 
 =head1 AUTHOR
 
@@ -86,7 +86,7 @@ John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by John SJ Anderson.
+This software is copyright (c) 2014 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
