@@ -1,12 +1,9 @@
 #ABSTRACT: Logging role
 
 package HiD::Role::DoesLogging;
-our $AUTHORITY = 'cpan:GENEHACK';
-$HiD::Role::DoesLogging::VERSION = '1.95_94'; # TRIAL
+$HiD::Role::DoesLogging::VERSION = '1.8'; # TRIAL
 use Moose::Role;
 
-use 5.014;  # strict, unicode_strings
-
 use Log::Log4perl;
 
 requires 'get_config';
@@ -99,7 +96,7 @@ Log4perl object for logging. Handles:
 
 =head1 VERSION
 
-version 1.95_94
+version 1.8
 
 =head1 AUTHOR
 
@@ -107,7 +104,7 @@ John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by John SJ Anderson.
+This software is copyright (c) 2014 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
