@@ -2,24 +2,24 @@
 
 
 package HiD::Role::IsConverted;
-our $AUTHORITY = 'cpan:GENEHACK';
-$HiD::Role::IsConverted::VERSION = '1.95_94'; # TRIAL
+$HiD::Role::IsConverted::VERSION = '1.8'; # TRIAL
 use Moose::Role;
 use namespace::autoclean;
 
-use 5.014; # strict, unicode_strings
+use 5.014;
 use utf8;
 use autodie;
 use warnings    qw/ FATAL  utf8     /;
 use open        qw/ :std  :utf8     /;
 use charnames   qw/ :full           /;
+use feature     qw/ unicode_strings /;
 
 use Carp;
-use Class::Load  qw/ load_class /;
-use Path::Tiny;
-use YAML::XS     qw/ Load /; # YAML::Tiny doesn't support 'bool' types which we need 8^/
-
+use Class::Load  qw/ :all /;
+use Encode;
+use File::Slurp  qw/ read_file /;
 use HiD::Types;
+use YAML::XS     qw/ Load /;
 
 requires 'get_default_layout';
 
@@ -158,7 +158,7 @@ around BUILDARGS => sub {
   my %args = ( ref $_[0] and ref $_[0] eq 'HASH' ) ? %{ $_[0] } : @_;
 
   unless ( $args{content} and $args{metadata} ) {
-    my $file_content = path( $args{input_filename} )->slurp_utf8;
+    my $file_content = read_file( $args{input_filename}, binmode => ':utf8' );
 
     my( $metadata , $content );
     if ( $file_content =~ /^---/ ) {
@@ -174,7 +174,7 @@ around BUILDARGS => sub {
     }
 
     $args{content}  = $content;
-    $args{metadata} = Load( $metadata ) // {};
+    $args{metadata} = Load( encode('utf8',$metadata) ) // {};
   }
 
   return $class->$orig( \%args );
@@ -281,7 +281,7 @@ Data for passing to template processing function.
 
 =head1 VERSION
 
-version 1.95_94
+version 1.8
 
 =head1 AUTHOR
 
@@ -289,7 +289,7 @@ John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by John SJ Anderson.
+This software is copyright (c) 2014 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
