@@ -2,22 +2,23 @@
 
 
 package HiD::Role::IsPost;
-our $AUTHORITY = 'cpan:GENEHACK';
-$HiD::Role::IsPost::VERSION = '1.95_94'; # TRIAL
+$HiD::Role::IsPost::VERSION = '1.8'; # TRIAL
 use Moose::Role;
 use namespace::autoclean;
 
-use 5.014; # strict, unicode_strings
+use 5.014;
 use utf8;
 use autodie;
 use warnings    qw/ FATAL  utf8     /;
 use open        qw/ :std  :utf8     /;
 use charnames   qw/ :full           /;
+use feature     qw/ unicode_strings /;
 
 use DateTime;
 use Date::Parse    qw/ str2time  /;
-
+use File::Basename qw/ fileparse /;
 use HiD::Types;
+use YAML::XS;
 
 
 has author => (
@@ -92,10 +93,9 @@ has date => (
       ( $year , $month , $day ) = $self->input_filename
         =~ m|^.*?/([0-9]{4})-([0-9]{1,2})-([0-9]{1,2})-|;
       return DateTime->new(
-        year      => $year ,
-        month     => $month ,
-        day       => $day ,
-        time_zone => 'UTC' ,
+        year  => $year ,
+        month => $month ,
+        day   => $day
       );
     }
   },
@@ -178,30 +178,21 @@ sub _build_title {
 }
 
 
-has twitter_handles => (
-  is      => 'ro' ,
-  isa     => 'ArrayRef[Str]' ,
-  lazy    => 1 ,
-  builder => '_build_twitter_handles' ,
-  traits  => [ 'Array' ],
-  handles => {
-      has_twitter_handles => 'count',
-      all_twitter_handles => 'elements',
-  },
+has twitter => (
+  is => 'ro' ,
+  isa => 'Maybe[Str]' ,
+  lazy => 1 ,
+  builder => '_build_twitter' ,
 );
 
-sub _build_twitter_handles {
+sub _build_twitter {
   my $self = shift;
 
-  my $t = $self->get_metadata('twitter');
+  my $twitter = $self->get_metadata( 'twitter' );
 
-  return ref $t ? $t : [ $t ? $t : () ];
+  return defined $twitter ? $twitter : undef;
 }
 
-
-sub twitter { ($_[0]->all_twitter_handles)[0] }
-
-
 around BUILDARGS => sub {
   my $orig  = shift;
   my $class = shift;
@@ -233,6 +224,7 @@ sub is_draft {
   return ( $self->input_filename =~ /^$drafts_dir/ ) ? 1 : 0;
 }
 
+
 no Moose::Role;
 1;
 
@@ -273,8 +265,7 @@ DateTime object for this post.
 
 =head2 description
 
-A one-line synopsis of the post (used, e.g., for metadata information used by
-Open Graph)
+A one-line synopsis of the post (used, e.g., for metadata information used by Open Graph)
 
 =head2 excerpt
 
@@ -286,27 +277,9 @@ want to list the full post on the front page.
 
 =head2 title
 
-=head2 twitter_handles
-
-Returns an arrayref of the twitter handles passed via
-the C<twitter> parameter.
-
-=head1 METHODS
-
-=head2 has_twitter_handles
-
-Returns c<true> if the post has any twitter handles associated with it, C<false>
-otherwise.
-
-=head2 all_twitter_handles
-
-Returns the list of the twitter handles associated with the post.
-
 =head2 twitter
 
-DEPRECATED: use <twitter_handles> instead.
-
-Returns the first twitter handle given to C<twitter>.
+=head1 METHODS
 
 =head2 all_tags
 
@@ -319,7 +292,7 @@ folder or not.
 
 =head1 VERSION
 
-version 1.95_94
+version 1.8
 
 =head1 AUTHOR
 
@@ -327,7 +300,7 @@ John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by John SJ Anderson.
+This software is copyright (c) 2014 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
