@@ -2,21 +2,21 @@
 
 
 package HiD::Role::IsPublished;
-our $AUTHORITY = 'cpan:GENEHACK';
-$HiD::Role::IsPublished::VERSION = '1.95_94'; # TRIAL
+$HiD::Role::IsPublished::VERSION = '1.8'; # TRIAL
 use Moose::Role;
 use namespace::autoclean;
 
-use 5.014; # strict, unicode_strings
+use 5.014;
 use utf8;
 use autodie;
 use warnings    qw/ FATAL  utf8     /;
 use open        qw/ :std  :utf8     /;
 use charnames   qw/ :full           /;
+use feature     qw/ unicode_strings /;
 
-use Path::Tiny;
-
+use File::Basename  qw/ fileparse /;
 use HiD::Types;
+use Path::Class     qw/ file /;
 
 requires 'publish';
 
@@ -31,7 +31,7 @@ has basename => (
 sub _build_basename {
   my $self = shift;
   my $ext = '.' . $self->ext;
-  return path( $self->input_filename )->basename( $ext );
+  return fileparse( $self->input_filename , $ext );
 }
 
 
@@ -45,8 +45,11 @@ has baseurl => (
 sub _build_baseurl {
   my $self = shift;
 
-  my $base_url = $self->get_config('baseurl');
-  return defined $base_url ? $base_url : '/';
+  my $base_url = $self->config->{baseurl};
+  if( defined $base_url ) {
+    return $base_url;
+  }
+  return '/';
 }
 
 
@@ -80,7 +83,11 @@ has input_path => (
   is      => 'ro' ,
   isa     => 'HiD_DirPath' ,
   lazy    => 1 ,
-  default => sub { path( shift->input_filename )->parent->stringify() },
+  default => sub {
+    my $self = shift;
+    my( undef , $path ) = fileparse( $self->input_filename );
+    return $path;
+  },
 );
 
 
@@ -94,7 +101,7 @@ has output_filename => (
     my $url = $self->url;
     $url .= 'index.html' if $url =~ m|/$|;
 
-    return path( $self->dest_dir , $url )->stringify;
+    return file( $self->dest_dir , $url )->stringify;
   },
 );
 
@@ -182,7 +189,7 @@ The URL to the output path for the written file.
 
 =head1 VERSION
 
-version 1.95_94
+version 1.8
 
 =head1 AUTHOR
 
@@ -190,7 +197,7 @@ John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by John SJ Anderson.
+This software is copyright (c) 2014 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
