@@ -1,8 +1,7 @@
 #ABSTRACT: Role for the 'publishes_drafts' attr
 
 package HiD::Role::PublishesDrafts;
-our $AUTHORITY = 'cpan:GENEHACK';
-$HiD::Role::PublishesDrafts::VERSION = '1.95_94'; # TRIAL
+$HiD::Role::PublishesDrafts::VERSION = '1.8'; # TRIAL
 use Moose::Role;
 
 requires '_run';
@@ -38,7 +37,7 @@ config key).
 
 =head1 VERSION
 
-version 1.95_94
+version 1.8
 
 =head1 AUTHOR
 
@@ -46,7 +45,7 @@ John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by John SJ Anderson.
+This software is copyright (c) 2014 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
