@@ -1,10 +1,6 @@
-# ABSTRACT: Helper for 'hid server'
-
-
 package HiD::Server;
-our $AUTHORITY = 'cpan:GENEHACK';
-$HiD::Server::VERSION = '1.95_94'; # TRIAL
-use 5.014; # strict, unicode_strings
+$HiD::Server::VERSION = '1.8'; # TRIAL
+use strict;
 use warnings;
 
 use parent 'Plack::App::File';
@@ -38,11 +34,7 @@ __END__
 
 =head1 NAME
 
-HiD::Server - Helper for 'hid server'
-
-=head1 DESCRIPTION
-
-Helper for C<hid server>
+HiD::Server
 
 =head1 METHODS
 
@@ -53,7 +45,7 @@ Overrides L<Plack::App::File>'s method of the same name to handle '/' and
 
 =head1 VERSION
 
-version 1.95_94
+version 1.8
 
 =head1 AUTHOR
 
@@ -61,7 +53,7 @@ John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by John SJ Anderson.
+This software is copyright (c) 2014 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
