@@ -1,10 +1,6 @@
-# ABSTRACT: Helper for 'hid publish -A'
-
-
 package HiD::Server::Handler;
-our $AUTHORITY = 'cpan:GENEHACK';
-$HiD::Server::Handler::VERSION = '1.95_94'; # TRIAL
-use 5.014;  # strict, unicode_strings
+$HiD::Server::Handler::VERSION = '1.8'; # TRIAL
+use strict;
 use warnings;
 
 use parent 'Plack::Handler::Standalone';
@@ -15,7 +11,7 @@ sub new {
 
   my $hid = delete $args{hid};
 
-  die "I must be passed something that can('publish') not a '$hid'!\n"
+  die "I must be passed a HiD not a $hid!"
     unless defined $hid and $hid->can('publish');
 
   my $self = $class->SUPER::new(%args);
@@ -51,7 +47,7 @@ __END__
 
 =head1 NAME
 
-HiD::Server::Handler - Helper for 'hid publish -A'
+HiD::Server::Handler
 
 =head1 METHODS
 
@@ -64,13 +60,9 @@ Constructor.
 Handles resetting the embedded L<HiD> object and calling the C<publish> method
 on it.
 
-=head1
-
-Helper for C<hid publish -A>
-
 =head1 VERSION
 
-version 1.95_94
+version 1.8
 
 =head1 AUTHOR
 
@@ -78,7 +70,7 @@ John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by John SJ Anderson.
+This software is copyright (c) 2014 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
