@@ -1,10 +1,6 @@
-# ABSTRACT: Another helper for 'hid publish -A'
-
-
 package HiD::Server::Loader;
-our $AUTHORITY = 'cpan:GENEHACK';
-$HiD::Server::Loader::VERSION = '1.95_94'; # TRIAL
-use 5.014;  # strict, unicode_strings
+$HiD::Server::Loader::VERSION = '1.8'; # TRIAL
+use strict;
 use warnings;
 
 use parent 'Plack::Loader::Restarter';
@@ -40,15 +36,11 @@ __END__
 
 =head1 NAME
 
-HiD::Server::Loader - Another helper for 'hid publish -A'
-
-=head1
-
-Another helper for C<hid publish -A>
+HiD::Server::Loader
 
 =head1 VERSION
 
-version 1.95_94
+version 1.8
 
 =head1 AUTHOR
 
@@ -56,7 +48,7 @@ John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by John SJ Anderson.
+This software is copyright (c) 2014 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
