@@ -2,15 +2,16 @@
 
 
 package HiD::Types;
-our $AUTHORITY = 'cpan:GENEHACK';
-$HiD::Types::VERSION = '1.95_94'; # TRIAL
-use 5.014; # strict, unicode_strings
+$HiD::Types::VERSION = '1.8'; # TRIAL
+use 5.014;
 use utf8;
+use strict;
 use autodie;
 use warnings;
 use warnings    qw/ FATAL  utf8     /;
 use open        qw/ :std  :utf8     /;
 use charnames   qw/ :full           /;
+use feature     qw/ unicode_strings /;
 
 use Moose::Util::TypeConstraints;
 
@@ -66,7 +67,7 @@ Type constraints for HiD.
 
 =head1 VERSION
 
-version 1.95_94
+version 1.8
 
 =head1 AUTHOR
 
@@ -74,7 +75,7 @@ John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by John SJ Anderson.
+This software is copyright (c) 2014 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
